ReceiveQueueHandler

Trait ReceiveQueueHandler 

pub trait ReceiveQueueHandler<D: Device, BC>: ReceiveQueueTypes<D, BC> {
    // Required method
    fn queue_rx_frame(
        &mut self,
        bindings_ctx: &mut BC,
        device_id: &Self::DeviceId,
        meta: Self::Meta,
        body: Self::Buffer,
    ) -> Result<(), ReceiveQueueFullError<(Self::Meta, Self::Buffer)>>;
}
An implementation of a receive queue, with a buffer.

Required Methods

fn queue_rx_frame( &mut self, bindings_ctx: &mut BC, device_id: &Self::DeviceId, meta: Self::Meta, body: Self::Buffer, ) -> Result<(), ReceiveQueueFullError<(Self::Meta, Self::Buffer)>>

Queues a frame for reception.

Errors

Returns an error with the metadata and body if the queue is full.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors